from enum import Enum

from ai.h2o.featurestore.api.v1 import CoreService_pb2 as pb


class SearchField(Enum):
    SEARCH_FIELD_FEATURE_NAME = 1
    SEARCH_FIELD_FEATURE_DESCRIPTION = 2
    SEARCH_FIELD_FEATURE_TAG = 3

    @classmethod
    def to_proto(cls, search_field):
        return {
            cls.SEARCH_FIELD_FEATURE_NAME: pb.AdvancedSearchOption.SearchField.SEARCH_FIELD_FEATURE_NAME,
            cls.SEARCH_FIELD_FEATURE_DESCRIPTION: pb.AdvancedSearchOption.SearchField.SEARCH_FIELD_FEATURE_DESCRIPTION,
            cls.SEARCH_FIELD_FEATURE_TAG: pb.AdvancedSearchOption.SearchField.SEARCH_FIELD_FEATURE_TAG,
        }[search_field]



from enum import Enum

import ai.h2o.featurestore.api.v1.FeatureSetProtoApi_pb2 as FeatureSetApi


class FeatureSetFlow(Enum):

    ONLINE_ONLY = 1
    OFFLINE_ONLY = 2
    OFFLINE_ONLINE_MANUAL = 3
    OFFLINE_ONLINE_AUTOMATIC = 4

    @staticmethod
    def _from_proto(flow: FeatureSetApi.FeatureSetFlow):
        if flow == FeatureSetApi.OFFLINE_ONLINE_AUTOMATIC:
            return FeatureSetFlow.OFFLINE_ONLINE_AUTOMATIC
        elif flow == FeatureSetApi.OFFLINE_ONLINE_MANUAL:
            return FeatureSetFlow.OFFLINE_ONLINE_MANUAL
        elif flow == FeatureSetApi.ONLINE_ONLY:
            return FeatureSetFlow.ONLINE_ONLY
        elif flow == FeatureSetApi.OFFLINE_ONLY:
            return FeatureSetFlow.OFFLINE_ONLY
        else:
            raise Exception("Unsupported flow" + str(flow))
